| Title: | Dataset for 'GOxploreR' |
|---|---|
| Description: | Contains the Gene ontology terms and skeleton for the reduced GO directed acyclic graph (DAG) for the organisms Rat and Mouse. The methods are explicitly discussed in the following article : Manjang et al (2020) <doi:10.1038/s41598-020-73326-3>. |
| Authors: | Kalifa Manjang |
| Maintainer: | Kalifa Manjang <[email protected]> |
| License: | GPL-2 |
| Version: | 1.1.0 |
| Built: | 2026-05-17 05:39:29 UTC |
| Source: | https://github.com/cran/gontr |
A data set with list containing information about the reduced GO-BP dag for Mouse
BPMouseBPMouse
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with list containing information about the reduced GO-BP dag for Rat.
BPRatBPRat
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with list containing information about the reduced GO-BP DAG for Mouse.
CCMouseCCMouse
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with list containing information about the reduced GO-BP DAG for Rat.
CCRatCCRat
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with list containing information about the reduced GO-BP DAG for Mouse.
MFMouseMFMouse
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with list containing information about the reduced GO-BP DAG for Rat
MFRatMFRat
A list with 3 objects:
GO-terms in the respective nodes.
Data frame object that shows how the respective nodes are connected.
Sketelon of the reduced GO-dags.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set containing BP, MF and CC GO-terms as an edgelist for Mouse.
MouseMouse
A list containing 3 objects:
BP GO-terms edgelist.
MF GO-terms edgelist.
CC GO-terms edgelist.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with all the GO-terms for Mouse.
MouseAllMouseAll
A data frame with 337505 rows and 2 variables:
The entrezgene_id.
The respective GO-terms.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set containing BP, MF and CC GO-terms as an edgelist for Rat
RatRat
A list containing 3 objects:
BP GO-terms edgelist.
MF GO-terms edgelist.
CC GO-terms edgelist.
<https://www.nature.com/articles/s41598-020-73326-3>
A data set with all the GO-terms for Rat.
RatAllRatAll
A data frame with 262619 rows and 2 variables:
The entrezgene_id.
The respective GO-terms.
<https://www.nature.com/articles/s41598-020-73326-3>